pub struct Pane { /* private fields */ }Implementations
Sourceimpl Pane
impl Pane
Sourcepub fn new(layout: Vec<StyledGraphemes>, offset: usize) -> Self
pub fn new(layout: Vec<StyledGraphemes>, offset: usize) -> Self
Constructs a new Pane with the specified layout, offset, and optional fixed height.
layout: A vector ofStyledGraphemesrepresenting the content of the pane.offset: The initial offset from the top of the pane.
pub fn visible_row_count(&self) -> usize
pub fn extract(&self, viewport_height: usize) -> Vec<StyledGraphemes>